//Verilog HDL for "ID_CEPC", "ID_FIFOController" "functional"


module ID_FIFOController (rstb,addr_wr,addr_rd,wr_req,rd_ack,clk,wr_enb,rd_enb,fifo_full,fifo_empty, datain, data_wr);
output [6:0]addr_wr;
output [6:0]addr_rd;
input wr_req;	//1.5 clk cycles
input rd_ack;	//1.5 clk cycles
input clk;
output wr_enb;
output rd_enb;
output fifo_full;
output fifo_empty;
input rstb;
input [31:0]datain;
output [31:0]data_wr;



reg [6:0]cnt;
reg wr_enb;
reg rd_enb;
reg [6:0]addr_wr;
reg [6:0]addr_rd;
reg [31:0]data_wr;

reg rd_ack_detected;


always@(negedge clk or negedge rstb)
begin
	if(!rstb)
	begin
		addr_wr<=0;
		addr_rd<=0;
		wr_enb<=1;
		rd_enb<=1;
		cnt<=0;
		data_wr<=0;
		rd_ack_detected<=0;
	end
	else
	begin
		if(!wr_req & !rd_ack)
		begin
			data_wr<=data_wr;
			rd_ack_detected<=0;
			wr_enb<=1;
			rd_enb<=1;
		end
		else if(wr_req & !rd_ack)	//write only
		begin
			rd_enb<=1;
			rd_ack_detected<=0;
			if(wr_enb && !fifo_full)
			begin
				wr_enb<=0;
				cnt<=cnt+1'b1;
				data_wr<=datain;
				addr_wr<=addr_wr+1'b1;
			end
			else
			begin
				wr_enb<=1;
			end		
		end
		else if(!wr_req & rd_ack)	//read_only
		begin
			wr_enb<=1;
			if(!rd_ack_detected && !fifo_empty)
			begin
				rd_enb<=0;
				cnt<=cnt-1'b1;
				addr_rd<=addr_rd+1'b1;
				rd_ack_detected<=1;
			end
		
		end
		else	//(wr_req & rd_ack)
		begin
			if(!rd_ack_detected)
			begin
				rd_ack_detected<=1;
				addr_rd<=(addr_rd==7'b1111111)?0:(addr_rd+1'b1);

				if(wr_enb)
				begin
					wr_enb<=0;
					data_wr<=datain;
					addr_wr<=(addr_wr==7'b1111111)?0:(addr_wr+1'b1);

				end
				else
				begin
					wr_enb<=1;
					cnt<=cnt-1'b1;
				end	
			end
			else
			begin
				if(wr_enb && !fifo_full)
				begin
					wr_enb<=0;
					cnt<=cnt+1'b1;
					data_wr<=datain;
					addr_wr<=addr_wr+1'b1;
				end
				else
				begin
					wr_enb<=1;
				end
			end

			
		
		end
		
	end
end

assign fifo_full=(cnt==7'b1111111)?1:0;
assign fifo_empty=(cnt==7'b0000000)?1:0;



endmodule
