//Verilog HDL for "ID_CEPC", "ID_FIFOController_col" "functional"


module ID_FIFOController_col (rstb,addr_wr,addr_rd,wr_req,rd_req,clk,wr_enb,rd_enb,fifo_full,fifo_empty, datain, data_wr );
output [5:0]addr_wr;
output [5:0]addr_rd;
input wr_req;	//1.5 clk cycles
input rd_req;	//1.5 clk cycles
input clk;
output wr_enb;
output rd_enb;
output fifo_full;
output fifo_empty;
input rstb;
input [23:0]datain;
output [23:0]data_wr;

reg [5:0]cnt;
reg wr_enb;
reg rd_enb;
reg [5:0]addr_wr;
reg [5:0]addr_rd;
reg [23:0]data_wr;




always@(negedge clk or negedge rstb)
begin
	if(~rstb)
	begin
		addr_wr<=0;
		addr_rd<=0;
		wr_enb<=1;
		rd_enb<=1;
		cnt<=0;
		data_wr<=0;
	end
	else
	begin
		if(~wr_req & ~rd_req)
		begin
			data_wr<=data_wr;
			wr_enb<=1;
			rd_enb<=1;
		end
		else if(wr_req & ~rd_req)	//write only
		begin
			rd_enb<=1;
			if(wr_enb && ~fifo_full)
			begin
				wr_enb<=0;
				cnt<=cnt+1'b1;
				data_wr<=datain;
				addr_wr<=addr_wr+1'b1;
			end
			else
			begin
				wr_enb<=1;
			end		
		end
		else if(~wr_req & rd_req)	//read_only
		begin
			wr_enb<=1;
			if(rd_enb && ~fifo_empty)
			begin
				rd_enb<=0;
				cnt<=cnt-1'b1;
				addr_rd<=addr_rd+1'b1;
			end
			else
			begin
				rd_enb<=1;
			end		
		end
		else if(wr_req & rd_req)
		begin
			if(rd_enb)
			begin
				rd_enb<=0;
				addr_rd<=(addr_rd==6'b111111)?0:(addr_rd+1'b1);
			end
			else
			begin
				rd_enb<=1;
			end
			
			if(wr_enb)
			begin
				wr_enb<=0;
				data_wr<=datain;
				addr_wr<=(addr_wr==6'b111111)?0:(addr_wr+1'b1);

			end
			else
			begin
				wr_enb<=1;
			end			
		end
		
	end
end

assign fifo_full=(cnt==6'b111111)?1:0;
assign fifo_empty=(cnt==6'b000000)?1:0;



endmodule
