// FE Release Version: 2.5.0 
//
//       CONFIDENTIAL AND PROPRIETARY SOFTWARE OF ARM PHYSICAL IP, INC.
//      
//       Copyright (c) 1993 - 2016 ARM Physical IP, Inc.  All Rights Reserved.
//      
//       Use of this Software is subject to the terms and conditions of the
//       applicable license agreement with ARM Physical IP, Inc.
//       In addition, this Software is protected by patents, copyright law 
//       and international treaties.
//      
//       The copyright notice(s) in this Software does not indicate actual or
//       intended publication of this Software.
//
//      Verilog model for Synchronous Dual-Port Register File
//
//      Instance Name:              rf_2p_hd_col
//      Words:                      64
//      Bits:                       24
//      Mux:                        1
//      Drive:                      4
//      Write Mask:                 Off
//      Extra Margin Adjustment:    Off
//      Accelerated Retention Test: Off
//      Redundant Rows:             0
//      Redundant Columns:          0
//      Test Muxes                  Off
//
//      Creation Date:  Wed Jul  6 14:21:25 2016
//      Version: 	r6p0-00eac0
//
//      Modeling Assumptions: This model supports full gate level simulation
//          including proper x-handling and timing check behavior.  Unit
//          delay timing is included in the model. Back-annotation of SDF
//          (v2.1) is supported.  SDF can be created utilyzing the delay
//          calculation views provided with this generator and supported
//          delay calculators.  All buses are modeled [MSB:LSB].  All 
//          ports are padded with Verilog primitives.
//
//      Modeling Limitations: None.
//
//      Known Bugs: None.
//
//      Known Work Arounds: N/A
//
`ifdef ARM_UD_MODEL

`timescale 1 ns/1 ps

`ifdef ARM_UD_DP
`else
`define ARM_UD_DP #0.001
`endif
`ifdef ARM_UD_CP
`else
`define ARM_UD_CP
`endif
`ifdef ARM_UD_SEQ
`else
`define ARM_UD_SEQ #0.01
`endif
`ifdef ARM_UD_CC
`else
`define ARM_UD_CC 0.1
`endif

`celldefine
`ifdef POWER_PINS
module rf_2p_hd_col (QA, CLKA, CENA, AA, CLKB, CENB, AB, DB, VDD, VSS);
`else
module rf_2p_hd_col (QA, CLKA, CENA, AA, CLKB, CENB, AB, DB);
`endif

  parameter BITS = 24;
  parameter WORDS = 64;
  parameter MUX = 1;
  parameter MEM_WIDTH = 24;
  parameter MEM_HEIGHT = 64;
  parameter WP_SIZE = 24 ;
  parameter UPM_WIDTH = 3;

  output [23:0] QA;
  input  CLKA;
  input  CENA;
  input [5:0] AA;
  input  CLKB;
  input  CENB;
  input [5:0] AB;
  input [23:0] DB;
`ifdef POWER_PINS
  inout VDD;
  inout VSS;
`endif

  integer row_address;
  integer mux_address;
  reg [23:0] mem [0:63];
  reg [23:0] row;
  reg LAST_CLKA;
  reg [23:0] data_out;
  reg [23:0] row_mask;
  reg [23:0] new_data;
  reg LAST_CLKB;
  reg [23:0] QA_int;
  reg [23:0] writeEnable;
  real previous_CLKA;
  real previous_CLKB;
  initial previous_CLKA = 0;
  initial previous_CLKB = 0;
  reg clk0_int;
  reg clk1_int;
  reg CRENA_legal;
  initial CRENA_legal = 1'b1;
  reg CRENB_legal;
  initial CRENB_legal = 1'b1;

  wire [23:0] QA_;
 wire  CLKA_;
  wire  CENA_;
  reg  CENA_int;
  wire [5:0] AA_;
  reg [5:0] AA_int;
 wire  CLKB_;
  wire  CENB_;
  reg  CENB_int;
  wire [5:0] AB_;
  reg [5:0] AB_int;
  wire [23:0] DB_;
  reg [23:0] DB_int;

  assign QA[0] = QA_[0]; 
  assign QA[1] = QA_[1]; 
  assign QA[2] = QA_[2]; 
  assign QA[3] = QA_[3]; 
  assign QA[4] = QA_[4]; 
  assign QA[5] = QA_[5]; 
  assign QA[6] = QA_[6]; 
  assign QA[7] = QA_[7]; 
  assign QA[8] = QA_[8]; 
  assign QA[9] = QA_[9]; 
  assign QA[10] = QA_[10]; 
  assign QA[11] = QA_[11]; 
  assign QA[12] = QA_[12]; 
  assign QA[13] = QA_[13]; 
  assign QA[14] = QA_[14]; 
  assign QA[15] = QA_[15]; 
  assign QA[16] = QA_[16]; 
  assign QA[17] = QA_[17]; 
  assign QA[18] = QA_[18]; 
  assign QA[19] = QA_[19]; 
  assign QA[20] = QA_[20]; 
  assign QA[21] = QA_[21]; 
  assign QA[22] = QA_[22]; 
  assign QA[23] = QA_[23]; 
  assign CLKA_ = CLKA;
  assign CENA_ = CENA;
  assign AA_[0] = AA[0];
  assign AA_[1] = AA[1];
  assign AA_[2] = AA[2];
  assign AA_[3] = AA[3];
  assign AA_[4] = AA[4];
  assign AA_[5] = AA[5];
  assign CLKB_ = CLKB;
  assign CENB_ = CENB;
  assign AB_[0] = AB[0];
  assign AB_[1] = AB[1];
  assign AB_[2] = AB[2];
  assign AB_[3] = AB[3];
  assign AB_[4] = AB[4];
  assign AB_[5] = AB[5];
  assign DB_[0] = DB[0];
  assign DB_[1] = DB[1];
  assign DB_[2] = DB[2];
  assign DB_[3] = DB[3];
  assign DB_[4] = DB[4];
  assign DB_[5] = DB[5];
  assign DB_[6] = DB[6];
  assign DB_[7] = DB[7];
  assign DB_[8] = DB[8];
  assign DB_[9] = DB[9];
  assign DB_[10] = DB[10];
  assign DB_[11] = DB[11];
  assign DB_[12] = DB[12];
  assign DB_[13] = DB[13];
  assign DB_[14] = DB[14];
  assign DB_[15] = DB[15];
  assign DB_[16] = DB[16];
  assign DB_[17] = DB[17];
  assign DB_[18] = DB[18];
  assign DB_[19] = DB[19];
  assign DB_[20] = DB[20];
  assign DB_[21] = DB[21];
  assign DB_[22] = DB[22];
  assign DB_[23] = DB[23];

  assign `ARM_UD_SEQ QA_ = QA_int;

`ifdef INITIALIZE_MEMORY
  integer i;
  initial
    for (i = 0; i < MEM_HEIGHT; i = i + 1)
      mem[i] = {MEM_WIDTH{1'b0}};
`endif

  task failedWrite;
  input port;
  integer i;
  begin
    for (i = 0; i < MEM_HEIGHT; i = i + 1)
      mem[i] = {MEM_WIDTH{1'bx}};
  end
  endtask

  function isBitX;
    input bitIn;
    begin
      isBitX = ( bitIn===1'bx || bitIn===1'bz ) ? 1'b1 : 1'b0;
    end
  endfunction


  task ReadA;
  begin
    if (^{CENA_int} === 1'bx) begin
      failedWrite(0);
      QA_int = {24{1'bx}};
    end else if ((AA_int >= WORDS) && (CENA_int === 1'b0)) begin
      QA_int = {24{1'bx}};
    end else if (CENA_int === 1'b0 && (^AA_int) === 1'bx) begin
      if (0) failedWrite(0);
      QA_int = {24{1'bx}};
    end else if (CENA_int === 1'b0) begin
      mux_address = 0;
      row_address = AA_int;
      if (row_address >= 64)
        row = {24{1'bx}};
      else
        row = mem[row_address];
      data_out = row;
      QA_int = data_out;
    end
  end
  endtask

  task WriteB;
  begin
    if (^{CENB_int} === 1'bx) begin
      failedWrite(1);
    end else if ((AB_int >= WORDS) && (CENB_int === 1'b0)) begin
    end else if (CENB_int === 1'b0 && (^AB_int) === 1'bx) begin
      if (1) failedWrite(1);
    end else if (CENB_int === 1'b0) begin
      mux_address = 0;
      row_address = AB_int;
      if (row_address >= 64)
        row = {24{1'bx}};
      else
        row = mem[row_address];
      writeEnable = ~{24{CENB_int}};
      row_mask =  writeEnable;
      new_data =  DB_int;
      row = (row & ~row_mask) | (row_mask & (~row_mask | new_data));
      mem[row_address] = row;
    end
  end
  endtask

  always @ CLKA_ begin
`ifdef POWER_PINS
    if (VDD === 1'bx || VDD === 1'bz)
      $display("ERROR: Illegal value for VDD %b", VDD);
    if (VSS === 1'bx || VSS === 1'bz)
      $display("ERROR: Illegal value for VSS %b", VSS);
`endif
    if (CLKA_ === 1'bx && (CENA_ !== 1'b1) ) begin
      failedWrite(0);
      QA_int = {24{1'bx}};
    end else if (CLKA_ === 1'b1 && LAST_CLKA === 1'b0) begin
    previous_CLKA = $realtime;
      CENA_int = CENA_;
      AA_int = AA_;
      clk0_int = 1'b0;
      ReadA;
      if (previous_CLKA == previous_CLKB && is_contention(AA_int, AB_int, 1'b1, 1'b0) && (CENA_int !== 1'b1 && CENB_int !== 1'b1) && 1) begin
         QA_int = {24{1'bx}};
      end
    end
    LAST_CLKA = CLKA_;
  end

  always @ CLKB_ begin
    if (CLKB_ === 1'bx && (CENB_ !== 1'b1)) begin
      failedWrite(0);
      QA_int = {24{1'bx}};
    end else if (CLKB_ === 1'b1 && LAST_CLKB === 1'b0) begin
    previous_CLKB = $realtime;
      CENB_int = CENB_;
      AB_int = AB_;
      DB_int = DB_;
      clk1_int = 1'b0;
      WriteB;
      if (previous_CLKA == previous_CLKB && is_contention(AA_int, AB_int, 1'b1, 1'b0) && (CENA_int !== 1'b1 && CENB_int !== 1'b1) && 1) begin
         QA_int = {24{1'bx}};
      end
    end
    LAST_CLKB = CLKB_;
  end


  function is_contention;
    input [5:0] aa;
    input [5:0] ab;
    input  wena;
    input  wenb;
    reg result;
  begin
    if ((& wena) === 1'b1 && (& wenb) === 1'b1) begin
      result = 1'b0;
    end else if (aa == ab) begin
      result = 1'b1;
    end else begin
      result = 1'b0;
    end
    is_contention = result;
  end
  endfunction


endmodule
`endcelldefine
`else
`timescale 1 ns/1 ps
`celldefine
`ifdef POWER_PINS
module rf_2p_hd_col (QA, CLKA, CENA, AA, CLKB, CENB, AB, DB, VDD, VSS);
`else
module rf_2p_hd_col (QA, CLKA, CENA, AA, CLKB, CENB, AB, DB);
`endif

  parameter BITS = 24;
  parameter WORDS = 64;
  parameter MUX = 1;
  parameter MEM_WIDTH = 24;
  parameter MEM_HEIGHT = 64;
  parameter WP_SIZE = 24 ;
  parameter UPM_WIDTH = 3;

  output [23:0] QA;
  input  CLKA;
  input  CENA;
  input [5:0] AA;
  input  CLKB;
  input  CENB;
  input [5:0] AB;
  input [23:0] DB;
`ifdef POWER_PINS
  inout VDD;
  inout VSS;
`endif

  integer row_address;
  integer mux_address;
  reg [23:0] mem [0:63];
  reg [23:0] row;
  reg LAST_CLKA;
  reg [23:0] data_out;
  reg [23:0] row_mask;
  reg [23:0] new_data;
  reg LAST_CLKB;
  reg [23:0] QA_int;
  reg [23:0] writeEnable;
  real previous_CLKA;
  real previous_CLKB;
  initial previous_CLKA = 0;
  initial previous_CLKB = 0;
  reg  cont_flag0_int;
  reg  cont_flag1_int;
  initial cont_flag0_int = 1'b0;
  initial cont_flag1_int = 1'b0;

  reg NOT_AA0, NOT_AA1, NOT_AA2, NOT_AA3, NOT_AA4, NOT_AA5, NOT_AB0, NOT_AB1, NOT_AB2;
  reg NOT_AB3, NOT_AB4, NOT_AB5, NOT_CENA, NOT_CENB, NOT_CLKA_MINH, NOT_CLKA_MINL;
  reg NOT_CLKA_PER, NOT_CLKB_MINH, NOT_CLKB_MINL, NOT_CLKB_PER, NOT_CONTA, NOT_CONTB;
  reg NOT_DB0, NOT_DB1, NOT_DB10, NOT_DB11, NOT_DB12, NOT_DB13, NOT_DB14, NOT_DB15;
  reg NOT_DB16, NOT_DB17, NOT_DB18, NOT_DB19, NOT_DB2, NOT_DB20, NOT_DB21, NOT_DB22;
  reg NOT_DB23, NOT_DB3, NOT_DB4, NOT_DB5, NOT_DB6, NOT_DB7, NOT_DB8, NOT_DB9;
  reg clk0_int;
  reg clk1_int;
  reg CRENA_legal;
  initial CRENA_legal = 1'b1;
  reg CRENB_legal;
  initial CRENB_legal = 1'b1;

  wire [23:0] QA_;
 wire  CLKA_;
  wire  CENA_;
  reg  CENA_int;
  wire [5:0] AA_;
  reg [5:0] AA_int;
 wire  CLKB_;
  wire  CENB_;
  reg  CENB_int;
  wire [5:0] AB_;
  reg [5:0] AB_int;
  wire [23:0] DB_;
  reg [23:0] DB_int;

  buf B0(QA[0], QA_[0]);
  buf B1(QA[1], QA_[1]);
  buf B2(QA[2], QA_[2]);
  buf B3(QA[3], QA_[3]);
  buf B4(QA[4], QA_[4]);
  buf B5(QA[5], QA_[5]);
  buf B6(QA[6], QA_[6]);
  buf B7(QA[7], QA_[7]);
  buf B8(QA[8], QA_[8]);
  buf B9(QA[9], QA_[9]);
  buf B10(QA[10], QA_[10]);
  buf B11(QA[11], QA_[11]);
  buf B12(QA[12], QA_[12]);
  buf B13(QA[13], QA_[13]);
  buf B14(QA[14], QA_[14]);
  buf B15(QA[15], QA_[15]);
  buf B16(QA[16], QA_[16]);
  buf B17(QA[17], QA_[17]);
  buf B18(QA[18], QA_[18]);
  buf B19(QA[19], QA_[19]);
  buf B20(QA[20], QA_[20]);
  buf B21(QA[21], QA_[21]);
  buf B22(QA[22], QA_[22]);
  buf B23(QA[23], QA_[23]);
  buf B24(CLKA_, CLKA);
  buf B25(CENA_, CENA);
  buf B26(AA_[0], AA[0]);
  buf B27(AA_[1], AA[1]);
  buf B28(AA_[2], AA[2]);
  buf B29(AA_[3], AA[3]);
  buf B30(AA_[4], AA[4]);
  buf B31(AA_[5], AA[5]);
  buf B32(CLKB_, CLKB);
  buf B33(CENB_, CENB);
  buf B34(AB_[0], AB[0]);
  buf B35(AB_[1], AB[1]);
  buf B36(AB_[2], AB[2]);
  buf B37(AB_[3], AB[3]);
  buf B38(AB_[4], AB[4]);
  buf B39(AB_[5], AB[5]);
  buf B40(DB_[0], DB[0]);
  buf B41(DB_[1], DB[1]);
  buf B42(DB_[2], DB[2]);
  buf B43(DB_[3], DB[3]);
  buf B44(DB_[4], DB[4]);
  buf B45(DB_[5], DB[5]);
  buf B46(DB_[6], DB[6]);
  buf B47(DB_[7], DB[7]);
  buf B48(DB_[8], DB[8]);
  buf B49(DB_[9], DB[9]);
  buf B50(DB_[10], DB[10]);
  buf B51(DB_[11], DB[11]);
  buf B52(DB_[12], DB[12]);
  buf B53(DB_[13], DB[13]);
  buf B54(DB_[14], DB[14]);
  buf B55(DB_[15], DB[15]);
  buf B56(DB_[16], DB[16]);
  buf B57(DB_[17], DB[17]);
  buf B58(DB_[18], DB[18]);
  buf B59(DB_[19], DB[19]);
  buf B60(DB_[20], DB[20]);
  buf B61(DB_[21], DB[21]);
  buf B62(DB_[22], DB[22]);
  buf B63(DB_[23], DB[23]);

  assign QA_ = QA_int;

`ifdef INITIALIZE_MEMORY
  integer i;
  initial
    for (i = 0; i < MEM_HEIGHT; i = i + 1)
      mem[i] = {MEM_WIDTH{1'b0}};
`endif

  task failedWrite;
  input port;
  integer i;
  begin
    for (i = 0; i < MEM_HEIGHT; i = i + 1)
      mem[i] = {MEM_WIDTH{1'bx}};
  end
  endtask

  function isBitX;
    input bitIn;
    begin
      isBitX = ( bitIn===1'bx || bitIn===1'bz ) ? 1'b1 : 1'b0;
    end
  endfunction


  task ReadA;
  begin
    if (^{CENA_int} === 1'bx) begin
      failedWrite(0);
      QA_int = {24{1'bx}};
    end else if ((AA_int >= WORDS) && (CENA_int === 1'b0)) begin
      QA_int = {24{1'bx}};
    end else if (CENA_int === 1'b0 && (^AA_int) === 1'bx) begin
      if (0) failedWrite(0);
      QA_int = {24{1'bx}};
    end else if (CENA_int === 1'b0) begin
      mux_address = 0;
      row_address = AA_int;
      if (row_address >= 64)
        row = {24{1'bx}};
      else
        row = mem[row_address];
      data_out = row;
      QA_int = data_out;
    end
  end
  endtask

  task WriteB;
  begin
    if (^{CENB_int} === 1'bx) begin
      failedWrite(1);
    end else if ((AB_int >= WORDS) && (CENB_int === 1'b0)) begin
    end else if (CENB_int === 1'b0 && (^AB_int) === 1'bx) begin
      if (1) failedWrite(1);
    end else if (CENB_int === 1'b0) begin
      mux_address = 0;
      row_address = AB_int;
      if (row_address >= 64)
        row = {24{1'bx}};
      else
        row = mem[row_address];
      writeEnable = ~{24{CENB_int}};
      row_mask =  writeEnable;
      new_data =  DB_int;
      row = (row & ~row_mask) | (row_mask & (~row_mask | new_data));
      mem[row_address] = row;
    end
  end
  endtask

  always @ CLKA_ begin
`ifdef POWER_PINS
    if (VDD === 1'bx || VDD === 1'bz)
      $display("ERROR: Illegal value for VDD %b", VDD);
    if (VSS === 1'bx || VSS === 1'bz)
      $display("ERROR: Illegal value for VSS %b", VSS);
`endif
    if (CLKA_ === 1'bx && (CENA_ !== 1'b1) ) begin
      failedWrite(0);
      QA_int = {24{1'bx}};
    end else if (CLKA_ === 1'b1 && LAST_CLKA === 1'b0) begin
    previous_CLKA = $realtime;
      CENA_int = CENA_;
      AA_int = AA_;
      clk0_int = 1'b0;
      ReadA;
      if (previous_CLKA == previous_CLKB && is_contention(AA_int, AB_int, 1'b1, 1'b0) && (CENA_int !== 1'b1 && CENB_int !== 1'b1) && 1) begin
         QA_int = {24{1'bx}};
      end
    end
    LAST_CLKA = CLKA_;
  end

  reg globalNotifier0;
  initial globalNotifier0 = 1'b0;
  initial cont_flag0_int = 1'b0;

  always @ globalNotifier0 begin
    if ($realtime == 0) begin
    end else if (CENA_int === 1'bx || clk0_int === 1'bx) begin
      QA_int = {24{1'bx}};
      failedWrite(0);
    end else if (cont_flag0_int === 1'bx) begin
      cont_flag0_int = 1'b0;
        if (1) begin
           QA_int = {24{1'bx}};
        end
    end else begin
      ReadA;
   end
    globalNotifier0 = 1'b0;
  end

  always @ CLKB_ begin
    if (CLKB_ === 1'bx && (CENB_ !== 1'b1)) begin
      failedWrite(0);
      QA_int = {24{1'bx}};
    end else if (CLKB_ === 1'b1 && LAST_CLKB === 1'b0) begin
    previous_CLKB = $realtime;
      CENB_int = CENB_;
      AB_int = AB_;
      DB_int = DB_;
      clk1_int = 1'b0;
      WriteB;
      if (previous_CLKA == previous_CLKB && is_contention(AA_int, AB_int, 1'b1, 1'b0) && (CENA_int !== 1'b1 && CENB_int !== 1'b1) && 1) begin
         QA_int = {24{1'bx}};
      end
    end
    LAST_CLKB = CLKB_;
  end

  reg globalNotifier1;
  initial globalNotifier1 = 1'b0;
  initial cont_flag1_int = 1'b0;

  always @ globalNotifier1 begin
    if ($realtime == 0) begin
    end else if (CENB_int === 1'bx || clk1_int === 1'bx) begin
      failedWrite(1);
    end else if (cont_flag1_int === 1'bx) begin
      cont_flag1_int = 1'b0;
        if (1) begin
           QA_int = {24{1'bx}};
        end
    end else begin
      WriteB;
   end
    globalNotifier1 = 1'b0;
  end

  always @ NOT_AA0 begin
    AA_int[0] = 1'bx;
    if ( globalNotifier0 === 1'b0 ) globalNotifier0 = 1'bx;
  end
  always @ NOT_AA1 begin
    AA_int[1] = 1'bx;
    if ( globalNotifier0 === 1'b0 ) globalNotifier0 = 1'bx;
  end
  always @ NOT_AA2 begin
    AA_int[2] = 1'bx;
    if ( globalNotifier0 === 1'b0 ) globalNotifier0 = 1'bx;
  end
  always @ NOT_AA3 begin
    AA_int[3] = 1'bx;
    if ( globalNotifier0 === 1'b0 ) globalNotifier0 = 1'bx;
  end
  always @ NOT_AA4 begin
    AA_int[4] = 1'bx;
    if ( globalNotifier0 === 1'b0 ) globalNotifier0 = 1'bx;
  end
  always @ NOT_AA5 begin
    AA_int[5] = 1'bx;
    if ( globalNotifier0 === 1'b0 ) globalNotifier0 = 1'bx;
  end
  always @ NOT_AB0 begin
    AB_int[0] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_AB1 begin
    AB_int[1] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_AB2 begin
    AB_int[2] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_AB3 begin
    AB_int[3] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_AB4 begin
    AB_int[4] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_AB5 begin
    AB_int[5] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_CENA begin
    CENA_int = 1'bx;
    if ( globalNotifier0 === 1'b0 ) globalNotifier0 = 1'bx;
  end
  always @ NOT_CENB begin
    CENB_int = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB0 begin
    DB_int[0] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB10 begin
    DB_int[10] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB11 begin
    DB_int[11] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB12 begin
    DB_int[12] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB13 begin
    DB_int[13] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB14 begin
    DB_int[14] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB15 begin
    DB_int[15] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB16 begin
    DB_int[16] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB17 begin
    DB_int[17] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB18 begin
    DB_int[18] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB19 begin
    DB_int[19] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB1 begin
    DB_int[1] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB20 begin
    DB_int[20] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB21 begin
    DB_int[21] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB22 begin
    DB_int[22] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB23 begin
    DB_int[23] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB2 begin
    DB_int[2] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB3 begin
    DB_int[3] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB4 begin
    DB_int[4] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB5 begin
    DB_int[5] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB6 begin
    DB_int[6] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB7 begin
    DB_int[7] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB8 begin
    DB_int[8] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_DB9 begin
    DB_int[9] = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_CLKA_MINH begin
    clk0_int = 1'bx;
    if ( globalNotifier0 === 1'b0 ) globalNotifier0 = 1'bx;
  end
  always @ NOT_CLKA_MINL begin
    clk0_int = 1'bx;
    if ( globalNotifier0 === 1'b0 ) globalNotifier0 = 1'bx;
  end
  always @ NOT_CLKA_PER begin
    clk0_int = 1'bx;
    if ( globalNotifier0 === 1'b0 ) globalNotifier0 = 1'bx;
  end
  always @ NOT_CLKB_MINH begin
    clk1_int = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_CLKB_MINL begin
    clk1_int = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_CLKB_PER begin
    clk1_int = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end
  always @ NOT_CONTB begin
    cont_flag0_int = 1'bx;
    if ( globalNotifier0 === 1'b0 ) globalNotifier0 = 1'bx;
  end
  always @ NOT_CONTA begin
    cont_flag1_int = 1'bx;
    if ( globalNotifier1 === 1'b0 ) globalNotifier1 = 1'bx;
  end

  function is_contention;
    input [5:0] aa;
    input [5:0] ab;
    input  wena;
    input  wenb;
    reg result;
  begin
    if ((& wena) === 1'b1 && (& wenb) === 1'b1) begin
      result = 1'b0;
    end else if (aa == ab) begin
      result = 1'b1;
    end else begin
      result = 1'b0;
    end
    is_contention = result;
  end
  endfunction

   wire contA_flag = is_contention(AB_, AA_int, 1'b0, 1'b1) & (CENB_ !== 1'b1 && CENA_int !== 1'b1);
   wire contB_flag = is_contention(AA_, AB_int, 1'b1, 1'b0) & (CENA_ !== 1'b1 && CENB_int !== 1'b1);

  wire CENA_flag;
  wire flagA;
  wire cyc_flagA;
  wire CENB_flag;
  wire flagB;
  wire DB_flag;
  wire cyc_flagB;
  assign CENA_flag = 1'b1;
  assign flagA = !CENA_;
  assign cyc_flagA = !CENA_;
  assign CENB_flag = 1'b1;
  assign flagB = !CENB_;
  assign DB_flag = !(CENB_);
  assign cyc_flagB = !CENB_;

  specify
      $setuphold(posedge CLKA &&& CENA_flag, posedge CENA, 1.000, 0.500, NOT_CENA);
      $setuphold(posedge CLKA &&& CENA_flag, negedge CENA, 1.000, 0.500, NOT_CENA);
      $setuphold(posedge CLKA &&& flagA, posedge AA[5], 1.000, 0.500, NOT_AA5);
      $setuphold(posedge CLKA &&& flagA, negedge AA[5], 1.000, 0.500, NOT_AA5);
      $setuphold(posedge CLKA &&& flagA, posedge AA[4], 1.000, 0.500, NOT_AA4);
      $setuphold(posedge CLKA &&& flagA, negedge AA[4], 1.000, 0.500, NOT_AA4);
      $setuphold(posedge CLKA &&& flagA, posedge AA[3], 1.000, 0.500, NOT_AA3);
      $setuphold(posedge CLKA &&& flagA, negedge AA[3], 1.000, 0.500, NOT_AA3);
      $setuphold(posedge CLKA &&& flagA, posedge AA[2], 1.000, 0.500, NOT_AA2);
      $setuphold(posedge CLKA &&& flagA, negedge AA[2], 1.000, 0.500, NOT_AA2);
      $setuphold(posedge CLKA &&& flagA, posedge AA[1], 1.000, 0.500, NOT_AA1);
      $setuphold(posedge CLKA &&& flagA, negedge AA[1], 1.000, 0.500, NOT_AA1);
      $setuphold(posedge CLKA &&& flagA, posedge AA[0], 1.000, 0.500, NOT_AA0);
      $setuphold(posedge CLKA &&& flagA, negedge AA[0], 1.000, 0.500, NOT_AA0);
      $setuphold(posedge CLKB &&& CENB_flag, posedge CENB, 1.000, 0.500, NOT_CENB);
      $setuphold(posedge CLKB &&& CENB_flag, negedge CENB, 1.000, 0.500, NOT_CENB);
      $setuphold(posedge CLKB &&& flagB, posedge AB[5], 1.000, 0.500, NOT_AB5);
      $setuphold(posedge CLKB &&& flagB, negedge AB[5], 1.000, 0.500, NOT_AB5);
      $setuphold(posedge CLKB &&& flagB, posedge AB[4], 1.000, 0.500, NOT_AB4);
      $setuphold(posedge CLKB &&& flagB, negedge AB[4], 1.000, 0.500, NOT_AB4);
      $setuphold(posedge CLKB &&& flagB, posedge AB[3], 1.000, 0.500, NOT_AB3);
      $setuphold(posedge CLKB &&& flagB, negedge AB[3], 1.000, 0.500, NOT_AB3);
      $setuphold(posedge CLKB &&& flagB, posedge AB[2], 1.000, 0.500, NOT_AB2);
      $setuphold(posedge CLKB &&& flagB, negedge AB[2], 1.000, 0.500, NOT_AB2);
      $setuphold(posedge CLKB &&& flagB, posedge AB[1], 1.000, 0.500, NOT_AB1);
      $setuphold(posedge CLKB &&& flagB, negedge AB[1], 1.000, 0.500, NOT_AB1);
      $setuphold(posedge CLKB &&& flagB, posedge AB[0], 1.000, 0.500, NOT_AB0);
      $setuphold(posedge CLKB &&& flagB, negedge AB[0], 1.000, 0.500, NOT_AB0);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[23], 1.000, 0.500, NOT_DB23);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[23], 1.000, 0.500, NOT_DB23);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[22], 1.000, 0.500, NOT_DB22);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[22], 1.000, 0.500, NOT_DB22);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[21], 1.000, 0.500, NOT_DB21);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[21], 1.000, 0.500, NOT_DB21);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[20], 1.000, 0.500, NOT_DB20);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[20], 1.000, 0.500, NOT_DB20);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[19], 1.000, 0.500, NOT_DB19);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[19], 1.000, 0.500, NOT_DB19);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[18], 1.000, 0.500, NOT_DB18);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[18], 1.000, 0.500, NOT_DB18);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[17], 1.000, 0.500, NOT_DB17);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[17], 1.000, 0.500, NOT_DB17);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[16], 1.000, 0.500, NOT_DB16);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[16], 1.000, 0.500, NOT_DB16);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[15], 1.000, 0.500, NOT_DB15);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[15], 1.000, 0.500, NOT_DB15);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[14], 1.000, 0.500, NOT_DB14);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[14], 1.000, 0.500, NOT_DB14);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[13], 1.000, 0.500, NOT_DB13);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[13], 1.000, 0.500, NOT_DB13);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[12], 1.000, 0.500, NOT_DB12);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[12], 1.000, 0.500, NOT_DB12);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[11], 1.000, 0.500, NOT_DB11);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[11], 1.000, 0.500, NOT_DB11);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[10], 1.000, 0.500, NOT_DB10);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[10], 1.000, 0.500, NOT_DB10);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[9], 1.000, 0.500, NOT_DB9);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[9], 1.000, 0.500, NOT_DB9);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[8], 1.000, 0.500, NOT_DB8);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[8], 1.000, 0.500, NOT_DB8);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[7], 1.000, 0.500, NOT_DB7);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[7], 1.000, 0.500, NOT_DB7);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[6], 1.000, 0.500, NOT_DB6);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[6], 1.000, 0.500, NOT_DB6);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[5], 1.000, 0.500, NOT_DB5);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[5], 1.000, 0.500, NOT_DB5);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[4], 1.000, 0.500, NOT_DB4);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[4], 1.000, 0.500, NOT_DB4);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[3], 1.000, 0.500, NOT_DB3);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[3], 1.000, 0.500, NOT_DB3);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[2], 1.000, 0.500, NOT_DB2);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[2], 1.000, 0.500, NOT_DB2);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[1], 1.000, 0.500, NOT_DB1);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[1], 1.000, 0.500, NOT_DB1);
      $setuphold(posedge CLKB &&& DB_flag, posedge DB[0], 1.000, 0.500, NOT_DB0);
      $setuphold(posedge CLKB &&& DB_flag, negedge DB[0], 1.000, 0.500, NOT_DB0);
      $setup(posedge CLKA, posedge CLKB &&& contA_flag, 3.000, NOT_CONTB);
      $setup(posedge CLKB, posedge CLKA &&& contB_flag, 3.000, NOT_CONTA);

      $width(posedge CLKA &&& cyc_flagA, 1.000, 0, NOT_CLKA_MINH);
      $width(negedge CLKA &&& cyc_flagA, 1.000, 0, NOT_CLKA_MINL);
      $period(posedge CLKA &&& cyc_flagA, 3.000, NOT_CLKA_PER);

      $width(posedge CLKB &&& cyc_flagB, 1.000, 0, NOT_CLKB_MINH);
      $width(negedge CLKB &&& cyc_flagB, 1.000, 0, NOT_CLKB_MINL);
      $period(posedge CLKB &&& cyc_flagB, 3.000, NOT_CLKB_PER);

      (posedge CLKA => (QA[23]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[22]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[21]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[20]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[19]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[18]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[17]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[16]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[15]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[14]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[13]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[12]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[11]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[10]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[9]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[8]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[7]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[6]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[5]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[4]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[3]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[2]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[1]:1'b0))=(1.000, 1.000);
      (posedge CLKA => (QA[0]:1'b0))=(1.000, 1.000);


  endspecify

endmodule
`endcelldefine
`endif
